@@ -163,6 +163,7 @@ if(isset($_GET['action'])) {
 		$auto_reset_remain=$_POST['auto_reset_remain'];
 		$auto_reset_remain_s=$_POST['auto_reset_remain_s'];
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
+		$month_remain_time=($_POST['month_limit_time']==-1)?-1:($_POST['month_limit_time']*60);
 
 		$sim_rs=$db->fetch_array($db->query("SELECT * FROM sim where sim_name='$sim_name'"));
 		if($sim_rs['time_limit']!=$_POST['time_limit']) $t_remain.=",remain_time=$_POST[time_limit]";
@@ -170,7 +171,7 @@ if(isset($_GET['action'])) {
 		if($sim_rs['limit_sms']!=$_POST['limit_sms']) $t_remain.=",remain_sms=$_POST[limit_sms]";
 		if($sim_rs['month_limit_time']!=$_POST['month_limit_time']) {
 			$db->query("insert into logs set sim_name='$sim_name', log='change month limit'");
-			$t_remain.=",month_remain_time=$_POST[month_limit_time],month_last_reset_time=now()";
+			$t_remain.=",month_remain_time=$month_remain_time,month_last_reset_time=now()";
 		}
 		if($sim_rs['no_connected_limit']!=$_POST['no_connected_limit']) $t_remain.=",no_connected_remain=$_POST[no_connected_limit]";
 		if($dev_disable==0 && $sim_rs['dev_disable']==1) $t_remain.",no_ring_remain==if(),no_answer_remain=0,short_call_remain=0";
@@ -248,6 +249,7 @@ if(isset($_GET['action'])) {
 		$where=gen_sim_where();
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
 		if($_POST[month_limit_time] == "" || $_POST[month_limit_time] < -1) $_POST[month_limit_time]=-1;
+		$month_remain_time=($_POST['month_limit_time']==-1)?-1:($_POST['month_limit_time']*60);
 		if($_POST[time_limit] == "" || $_POST[time_limit] < -1) $_POST[time_limit]=-1;
 		if($_POST[limit_sms] == "" || $_POST[limit_sms] < -1) $_POST[limit_sms]=-1;
                 if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
@@ -265,7 +267,7 @@ if(isset($_GET['action'])) {
 			$sql="UPDATE sim SET ";
 			if($_POST['team_id_modify']) $sql.="sim_team_id='$team_id',";
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
-			if($_POST['month_limit_time_modify']) $sql.="month_limit_time='$_POST[month_limit_time]',month_remain_time='$_POST[month_limit_time]',month_last_reset_time=now(),";
+			if($_POST['month_limit_time_modify']) $sql.="month_limit_time='$_POST[month_limit_time]',month_remain_time='$month_remain_time',month_last_reset_time=now(),";
 			if($_POST['month_reset_day_modify']) $sql.="month_reset_day='$_POST[month_reset_day]',";
 			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
 			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
@@ -323,7 +325,7 @@ if(isset($_GET['action'])) {
 	}
 	else if($action=="reset_limit"){
 		$where=gen_sim_where();
-		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,remain_sms=limit_sms,count_remain=count_limit,no_connected_remain=no_connected_limit,month_remain_time=month_limit_time $where");
+		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,remain_sms=limit_sms,count_remain=count_limit,no_connected_remain=no_connected_limit,month_remain_time=if(month_limit_time=-1, -1, month_limit_time*60) $where");
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 		while($row=$db->fetch_array($query)) {
@@ -501,6 +503,10 @@ if(isset($_GET['action'])) {
 			else if($row['imei_mode']==2) $row['imei_type_name']="Set with SIM";
 			else if($row['imei_mode']==3) $row['imei_type_name']="Random with IMSI";
 			else if($row['imei_mode']==4) $row['imei_type_name']="Database with IMSI";
+			if($row['month_remain_time']!=-1 && $row['month_remain_time']!=0){
+				if($row['month_remain_time'] < 60) $row['month_remain_time'] = 1; 
+				else $row['month_remain_time'] = floor($row['month_remain_time']/60);
+			}
 
 			$row['remain_limit']="total remain time: ".$row['remain_time']."/".$row['time_limit']."\n";
                         $row['remain_limit'].="total remain count: ".$row['count_remain']."/".$row['count_limit']."\n";
