@@ -130,8 +130,8 @@ if(isset($_GET['action'])) {
 			//      if($attach_ext == 'php' || empty($attach_ext) || !@in_array($attach_ext,$available_type)){
 			//              showerror('对不起，您上传的文件类型已被系统禁止！');
 			//      }
-			if($attach_ext != '.xls' && $attach_ext != '.cvs'){
-				WriteErrMsg('The type of file you uploaded has been banned!');
+			if($attach_ext != 'xls' && $attach_ext != 'csv'){
+				WriteErrMsg('The type of file you uploaded has been banned!'.$attach_ext);
 			}
 
 			$randvar=num_rand('15');
