@@ -417,6 +417,11 @@
 /* 1.10-t1 set IMEI befor bind when IMEI MODE=IMEI-IMSI datebase */
 /* 1.10-t2 add simnum*/
 	@$db->updatequery("ALTER TABLE `sim` ADD `simnum` VARCHAR( 32 ) NOT NULL");
+	if(!$rs || $rs[0] < 114){
+		@$db->updatequery("update sim set month_remain_time=if(month_remain_time=-1, -1, month_remain_time*60)");
+		@$db->updatequery("update `system` set `version`='114'");
+	}
+
 /* 1.10-t3 fixed bug of dial in api.php */
 /* 1.11 fixed bug of period time*/
 /* 1.12 remove &$ */
@@ -435,6 +440,7 @@
 /* 1.17.2 fixed bug of disable sim  */
 /* 1.18 fixed bug of upload  */
 /* 1.19 fixed bug of upload  */
+/* 1.20 month_remain_time use second  */
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 ?>
